/************************************************************************/
/*		aPCI-P31 Device Driver											*/
/*																		*/
/*			apci31.h	-	Win32 interface definition					*/
/************************************************************************/

#if !defined( APCI31_H )
#define	APCI31_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI31_SUCCESS				0	/* Successfully proccessed */
#define	APCI31_ERR_SYSTEM			1	/* Call GetLastError() */
#define	APCI31_ERR_NO_DEVICE		2	/* No card */
#define	APCI31_ERR_IN_USE			3	/* Device is in use */
#define	APCI31_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI31_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI31_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI31_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI31_ERR_NO_CREATE		8	/* No created device */

/*==========================================*/
/*	aPCI-P31 card's relative port address	*/
/*==========================================*/
#define	APCI31_PORT_1	0
#define	APCI31_PORT_2	1
#define	APCI31_PORT_3	2
#define	APCI31_PORT_4	3

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI31_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI31_MAX_PORTS	4			/* Maximum number of user ports */

										/* default search */
#define	APCI31_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI31_BOARD_ID		0x9031		/* pci bus device id */
#define	APCI31_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI31_DEVICE_ID	( ( DWORD )APCI31_BOARD_ID\
							| ( ( DWORD )APCI31_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI31_MAX_MEM		9			/* number of memory windows */
#define	APCI31_MAX_IO		20			/* number of i/o windows */
#define	APCI31_MAX_IRQ		7			/* number of irqs */
#define	APCI31_MAX_DMA		7			/* number of dmas */

typedef	struct	_APCI31RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI31_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI31_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI31_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI31_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI31_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI31_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI31_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI31_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI31_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI31RESOURCE, *PAPCI31R;

#if !defined( APCI31_DRIVER )
#define	APCI31_API

#if !defined( APCI31_DLL )
	#define APCI31LIB_API	extern __declspec( dllimport )
#else
	#define APCI31LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI31LIB_API BOOL	WINAPI	Apci31GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI31LIB_API BOOL	WINAPI	Apci31Create( PWORD pwLogSlot );
APCI31LIB_API BOOL	WINAPI	Apci31Close( WORD wLogSlot );
APCI31LIB_API BOOL	WINAPI	Apci31GetResource( WORD wLogSlot, PAPCI31R pres );
APCI31LIB_API BOOL	WINAPI	Apci31GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI31LIB_API BOOL	WINAPI	Apci31InPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI31LIB_API BOOL	WINAPI	Apci31OutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI31LIB_API DWORD	WINAPI	Apci31GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI31_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI31_H ) */

/**/